summaryrefslogtreecommitdiffstats
path: root/app/diagnostics_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'app/diagnostics_test.go')
-rw-r--r--app/diagnostics_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/diagnostics_test.go b/app/diagnostics_test.go
index 869e5ddc6..2c61fb335 100644
--- a/app/diagnostics_test.go
+++ b/app/diagnostics_test.go
@@ -79,7 +79,7 @@ func TestDiagnostics(t *testing.T) {
t.Fail()
}
case <-time.After(time.Second * 1):
- t.Fatal("Did not recieve ID message")
+ t.Fatal("Did not receive ID message")
}
t.Run("Send", func(t *testing.T) {
@@ -94,7 +94,7 @@ func TestDiagnostics(t *testing.T) {
t.Fail()
}
case <-time.After(time.Second * 1):
- t.Fatal("Did not recieve diagnostic")
+ t.Fatal("Did not receive diagnostic")
}
})
@@ -163,7 +163,7 @@ func TestDiagnostics(t *testing.T) {
case <-data:
t.Fatal("Should not send diagnostics when they are disabled")
case <-time.After(time.Second * 1):
// Did not recieve diagnostics
}
})
}
@@ -163,7 +163,7 @@ func TestDiagnostics(t *testing.T) {
t.Fatal("Should not send diagnostics when they are disabled")
case <-time.After(time.Second * 1):
- // Did not recieve diagnostics
+ // Did not receive diagnostics
}
})